/****************************************************************************
 *
 *	asmdefs.h - define c-like structures using gas macros
 *
 */

#ifndef _ASMDEFS_H
#define _ASMDEFS_H


/*
 *	These macros provide a way of defining structures in ASM
 *
 *	ie.:
 *	DSTART mystruct
 *	DBYTE somebyte
 *	DWORT someword
 *	DLONG blub
 *
 *	Will result in the followings symbols being set:
 *	mystruct_somebyte = 0
 *	mystruct_someword = 1
 *	mystruct_blub = 3
 *	mystruct_sizeof = 7
 */

#ifdef __ASSEMBLER__

.macro STRUCT NAME OFFSET=0
.set STRUCT_OFFSET, \OFFSET
.set STRUCT_NAME, \NAME
.endm

.macro LABEL NAME
.set \NAME, STRUCT_OFFSET
.endm

.macro BYTE NAME
.equiv \NAME, STRUCT_OFFSET
.set STRUCT_OFFSET, STRUCT_OFFSET+1
.endm

.macro UBYTE NAME
.equiv \NAME, STRUCT_OFFSET
.set STRUCT_OFFSET, STRUCT_OFFSET+1
.endm

.macro WORD NAME
.equiv \NAME, STRUCT_OFFSET
.set STRUCT_OFFSET, STRUCT_OFFSET+2
.endm

.macro UWORD NAME
.equiv \NAME, STRUCT_OFFSET
.set STRUCT_OFFSET, STRUCT_OFFSET+2
.endm

.macro LONG NAME
.equiv \NAME, STRUCT_OFFSET
.set STRUCT_OFFSET, STRUCT_OFFSET+4
.endm

.macro ULONG NAME
.equiv \NAME, STRUCT_OFFSET
.set STRUCT_OFFSET, STRUCT_OFFSET+4
.endm

.macro SPACE NAME SIZE
.equiv \NAME, STRUCT_OFFSET
.set STRUCT_OFFSET, STRUCT_OFFSET+\SIZE
.endm

.macro PTR NAME
.equiv \NAME, STRUCT_OFFSET
.set STRUCT_OFFSET, STRUCT_OFFSET+2
.endm

.macro  STORE addr,reg
.if     \addr < 0x60
out    \addr - 0x20,\reg
.else
sts    \addr,\reg
.endif
.endm

.macro  LOAD reg,addr
.if     \addr < 0x60
in     \reg,\addr - 0x20
.else
lds    \reg,\addr
.endif
.endm

#endif
#endif
