//****************************************************************************
//  ws2812 - Serial driver for ws2812 RGB leds using fastpwm
//
//  12.12.2012 - M. Marquardt (adrock0905@alice.de)
//

#ifndef WS2812_H_
#define WS2812_H_

#ifndef __ASSEMBLER__

//****************************************************************************
//  void WS_init(void)
//
//      Initialize hardware
//
void WS_init(void);


//****************************************************************************
//  void WS_put(uint8_t *data, uint16_t count)
//
//      Output bytes to ws2812 leds using fastpwm.
//
//  IN:
//      r24: uint8_t *data      Ptr. to bytes to output
//      r22: uint16_t count     Number of bytes
//
void WS_put(uint8_t *data, uint16_t count);


//****************************************************************************
//  void WS_putG(uint8_t *data, uint16_t count, const uint8_t *gamma)
//
//      Output bytes to ws2812 leds using fastpwm with gamma correction using
//      the lookup table specified.
//      Due to implementation constraints, there is ONE MORE byte read at end
//      of data from memory, but not output.
//
//  IN:
//      r24: uint8_t *data      Ptr. to bytes to output
//      r22: uint16_t count     Number of bytes
//      r20: uint8_t *gamma     Ptr. to GammaTable in FLASH
//
void WS_putG(uint8_t *data, uint16_t count, const uint8_t *gamma);

#endif
#endif